[![MORAILog](./docs/MORAI_Logo.png)](https://www.morai.ai)
===
# MORAI - Sensor Kit (gRPC)

Welcome to the sensor tool kit of the MORAI SIM.

# MORAI Kit setup

Our morai-kit is available and can be installed via pip :
```
$ pip install morai-kit
```

# Tutorial

Please follow these steps to make yourself familiar with the MORAI Sensor Kit:
* Install jupyter notebook
```
$ pip install jupyter
```
* Run the tutorial using:
```
$ jupyter notebook $HOME/moraikit_tutorial.ipynb
```

# License
- MORAI Kit license info details:  [MORAI Kit License](./docs/LICENSE.md)